==> dokuwiki-2020.07.29p0.tgz: dokuwiki/lib/plugins/extension/lang/cs/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Petr Kajzar <petr.kajzar@lf1.cuni.cz>
 * @author Viktor Zavadil <vzavadil@newps.cz>
 * @author Jaroslav Lichtblau <jlichtblau@seznam.cz>
 * @author Turkislav <turkislav@blabla.com>
 * @author Martin Růžička <martinr@post.cz>
 */
$lang['menu']                  = 'Správa rozšíření';
$lang['tab_plugins']           = 'Instalované moduly';
$lang['tab_templates']         = 'Instalované šablony';
$lang['tab_search']            = 'Vyhledej a instaluj';
$lang['tab_install']           = 'Ruční instalace';
$lang['notimplemented']        = 'Tato vychytávka není dosud implementována';
$lang['notinstalled']          = 'Toto rozšíření není instalováno';
$lang['alreadyenabled']        = 'Toto rozšíření je již povoleno';
$lang['alreadydisabled']       = 'Toto rozšíření je již vypnuto';
$lang['pluginlistsaveerror']   = 'Došlo k chybě při ukládání seznamu zásuvných modulů';
$lang['unknownauthor']         = 'Neznámý autor';
$lang['unknownversion']        = 'Neznámá verze';
$lang['btn_info']              = 'Zobrazit více informací';
$lang['btn_update']            = 'Aktualizovat';
$lang['btn_uninstall']         = 'Odinstalovat';
$lang['btn_enable']            = 'Povolit';
$lang['btn_disable']           = 'Zakázat';
$lang['btn_install']           = 'Instalovat';
$lang['btn_reinstall']         = 'Přeinstalovat';
$lang['js']['reallydel']       = 'Opravdu odinstalovat toto rozšíření?';
$lang['js']['display_viewoptions'] = 'Zobrazit možnosti:';
$lang['js']['display_enabled'] = 'povolit';
$lang['js']['display_disabled'] = 'zakázat';
$lang['js']['display_updatable'] = 'aktualizovatelné';
$lang['search_for']            = 'Hledat rozšíření:';
$lang['search']                = 'Hledat';
$lang['extensionby']           = '<strong>%s</strong> od %s';
$lang['screenshot']            = 'Screenshot %s';
$lang['popularity']            = 'Popularita: %s%%';
$lang['homepage_link']         = 'Dokumenty';
$lang['bugs_features']         = 'Chyby';
$lang['tags']                  = 'Štítky:';
$lang['author_hint']           = 'Vyhledat rozšíření podle tohoto autora';
$lang['installed']             = 'Nainstalováno:';
$lang['downloadurl']           = 'URL stahování:';
$lang['repository']            = 'Repozitář:';
$lang['unknown']               = '<em>neznámý</em>';
$lang['installed_version']     = 'Nainstalovaná verze:';
$lang['install_date']          = 'Poslední aktualizace';
$lang['available_version']     = 'Dostupná verze:';
$lang['compatible']            = 'Kompatibilní s:';
$lang['depends']               = 'Závisí na:';
$lang['similar']               = 'Podobný jako:';
$lang['conflicts']             = 'Koliduje s:';
$lang['donate']                = 'Líbí se ti to?';
$lang['donate_action']         = 'Kup autorovi kávu!';
$lang['repo_retry']            = 'Opakovat';
$lang['provides']              = 'Poskytuje:';
$lang['status']                = 'Stav:';
$lang['status_installed']      = 'instalovaný';
$lang['status_not_installed']  = 'nenainstalovaný';
$lang['status_protected']      = 'chráněný';
$lang['status_enabled']        = 'povolený';
$lang['status_disabled']       = 'zakázaný';
$lang['status_unmodifiable']   = 'neměnný';
$lang['status_plugin']         = 'zásuvný modul';
$lang['status_template']       = 'šablona';
$lang['status_bundled']        = 'svázaný';
$lang['msg_enabled']           = 'Zásuvný modul %s povolen';
$lang['msg_disabled']          = 'Zásuvný modul %s zakázán';
$lang['msg_delete_success']    = 'Rozšíření %s odinstalováno';
$lang['msg_delete_failed']     = 'Odinstalování rozšíření %s selhalo';
$lang['msg_template_install_success'] = 'Šablona %s úspěšně nainstalována';
$lang['msg_template_update_success'] = 'Šablona %s úspěšně aktualizována';
$lang['msg_plugin_install_success'] = 'Zásuvný modul %s úspěšně nainstalován.';
$lang['msg_plugin_update_success'] = 'Zásuvný modul %s úspěšně aktualizován.';
$lang['msg_upload_failed']     = 'Nahrávání souboru selhalo';
$lang['msg_nooverwrite']       = 'Rozšíření %s již existuje, proto nebylo přepsáno; pro přepsání zatrhněte příslušnou možnost';
$lang['missing_dependency']    = '<strong>Chybějící nebo zakázaná závislost:</strong> %s';
$lang['security_issue']        = '<strong>Bezpečnostní problém:</strong> %s';
$lang['security_warning']      = '<strong>Bezpečnostní varování:</strong> %s';
$lang['update_available']      = '<strong>Aktualizace:</strong> Je dostupná nová verze %s.';
$lang['wrong_folder']          = '<strong>Zásuvný modul nesprávně nainstalován:</strong> Přejmenujte adresář modulu "%s" na "%s".';
$lang['url_change']            = '<strong>URL se změnila:</strong> URL pro stahování se změnila od poslední aktualizace. Před další aktualizací tohoto rozšíření ověřte správnost nové URL.<br />Nová: %s<br />Stará: %s';
$lang['error_badurl']          = 'Adresy URL by měly začínat s http nebo https';
$lang['error_dircreate']       = 'Nelze vytvořit dočasný adresář pro přijetí stahování';
$lang['error_download']        = 'Nelze stáhnout soubor: %s';
$lang['error_decompress']      = 'Selhalo rozbalení staženého souboru. Toto je nejspíš důsledek poškození souboru při přenosu, zkuste soubor stáhnout znovu; případně nemusel být rozpoznán formát sbaleného souboru a bude třeba přistoupit k ruční instalaci. ';
$lang['error_findfolder']      = 'Nelze rozpoznat adresář pro rozšíření, je třeba stáhnout a instalovat ručně';
$lang['error_copy']            = 'Došlo k chybě kopírování souborů při pokusu nainstalovat soubory do adresáře <em>%s</em>: může být plný disk nebo špatně nastavena přístupová práva. Tato chyba mohla zapříčinit pouze částečnou instalaci zásuvného modulu a uvést wiki do nestabilního stavu.';
$lang['noperms']               = 'Nelze zapisovat do adresáře pro rozšíření';
$lang['notplperms']            = 'Nelze zapisovat do odkládacího adresáře';
$lang['nopluginperms']         = 'Nelze zapisovat do adresáře se zásuvnými moduly';
$lang['git']                   = 'Toto rozšíření bylo nainstalováno přes git. Touto cestou ho nejspíš tady aktualizovat nechcete.';
$lang['auth']                  = 'Tento ověřovací zásuvný modul není povolen v nastavení, zvažte jeho deaktivaci.';
$lang['install_url']           = 'Nainstalovat z URL:';
$lang['install_upload']        = 'Nahrát rozšíření:';
$lang['repo_error']            = 'Nelze kontaktovat repozitář se zásuvnými moduly. Ujistěte se, že váš server může kontaktovat www.dokuwiki.org a zkontrolujte nastavení proxy.';
$lang['nossl']                 = 'Použité PHP pravděpodobně nepodporuje SSL. Stažení mnoha DokuWiki rozšíření nebude fungovat.';

==> dokuwiki-2024.02.06p0.tgz: dokuwiki/lib/plugins/extension/lang/cs/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Martin Růžička <martinr@post.cz>
 * @author Petr Kajzar <petr.kajzar@lf1.cuni.cz>
 * @author Viktor Zavadil <vzavadil@newps.cz>
 * @author Jaroslav Lichtblau <jlichtblau@seznam.cz>
 * @author Turkislav <turkislav@blabla.com>
 */
$lang['menu']                  = 'Správa rozšíření';
$lang['tab_plugins']           = 'Instalované moduly';
$lang['tab_templates']         = 'Instalované šablony';
$lang['tab_search']            = 'Vyhledat a instalovat';
$lang['tab_install']           = 'Ruční instalace';
$lang['notimplemented']        = 'Tato vychytávka není dosud implementována';
$lang['notinstalled']          = 'Toto rozšíření není instalováno';
$lang['alreadyenabled']        = 'Toto rozšíření je již povoleno';
$lang['alreadydisabled']       = 'Toto rozšíření je již vypnuto';
$lang['pluginlistsaveerror']   = 'Došlo k chybě při ukládání seznamu zásuvných modulů';
$lang['unknownauthor']         = 'Neznámý autor';
$lang['unknownversion']        = 'Neznámá verze';
$lang['btn_info']              = 'Zobrazit více informací';
$lang['btn_update']            = 'Aktualizovat';
$lang['btn_uninstall']         = 'Odinstalovat';
$lang['btn_enable']            = 'Povolit';
$lang['btn_disable']           = 'Zakázat';
$lang['btn_install']           = 'Instalovat';
$lang['btn_reinstall']         = 'Přeinstalovat';
$lang['js']['reallydel']       = 'Opravdu odinstalovat toto rozšíření?';
$lang['js']['display_viewoptions'] = 'Zobrazit možnosti:';
$lang['js']['display_enabled'] = 'povolené';
$lang['js']['display_disabled'] = 'zakázané';
$lang['js']['display_updatable'] = 'aktualizovatelné';
$lang['search_for']            = 'Hledat rozšíření:';
$lang['search']                = 'Hledat';
$lang['extensionby']           = '<strong>%s</strong> od %s';
$lang['screenshot']            = 'Screenshot %s';
$lang['popularity']            = 'Popularita: %s%%';
$lang['homepage_link']         = 'Dokumenty';
$lang['bugs_features']         = 'Chyby';
$lang['tags']                  = 'Štítky:';
$lang['author_hint']           = 'Vyhledat rozšíření podle tohoto autora';
$lang['installed']             = 'Nainstalováno:';
$lang['downloadurl']           = 'URL stahování:';
$lang['repository']            = 'Repozitář:';
$lang['unknown']               = '<em>neznámý</em>';
$lang['installed_version']     = 'Nainstalovaná verze:';
$lang['install_date']          = 'Poslední aktualizace';
$lang['available_version']     = 'Dostupná verze:';
$lang['compatible']            = 'Kompatibilní s:';
$lang['depends']               = 'Závisí na:';
$lang['similar']               = 'Podobný jako:';
$lang['conflicts']             = 'Koliduje s:';
$lang['donate']                = 'Líbí se ti to?';
$lang['donate_action']         = 'Kup autorovi kávu!';
$lang['repo_retry']            = 'Opakovat';
$lang['provides']              = 'Poskytuje:';
$lang['status']                = 'Stav:';
$lang['status_installed']      = 'instalovaný';
$lang['status_not_installed']  = 'nenainstalovaný';
$lang['status_protected']      = 'chráněný';
$lang['status_enabled']        = 'povolený';
$lang['status_disabled']       = 'zakázaný';
$lang['status_unmodifiable']   = 'neměnný';
$lang['status_plugin']         = 'zásuvný modul';
$lang['status_template']       = 'šablona';
$lang['status_bundled']        = 'svázaný';
$lang['msg_enabled']           = 'Zásuvný modul %s povolen';
$lang['msg_disabled']          = 'Zásuvný modul %s zakázán';
$lang['msg_delete_success']    = 'Rozšíření %s odinstalováno';
$lang['msg_delete_failed']     = 'Odinstalování rozšíření %s selhalo';
$lang['msg_template_install_success'] = 'Šablona %s úspěšně nainstalována';
$lang['msg_template_update_success'] = 'Šablona %s úspěšně aktualizována';
$lang['msg_plugin_install_success'] = 'Zásuvný modul %s úspěšně nainstalován.';
$lang['msg_plugin_update_success'] = 'Zásuvný modul %s úspěšně aktualizován.';
$lang['msg_upload_failed']     = 'Nahrávání souboru selhalo';
$lang['msg_nooverwrite']       = 'Rozšíření %s již existuje, proto nebylo přepsáno; pro přepsání zatrhněte příslušnou možnost';
$lang['missing_dependency']    = '<strong>Chybějící nebo zakázaná závislost:</strong> %s';
$lang['security_issue']        = '<strong>Bezpečnostní problém:</strong> %s';
$lang['security_warning']      = '<strong>Bezpečnostní varování:</strong> %s';
$lang['update_available']      = '<strong>Aktualizace:</strong> Je dostupná nová verze %s.';
$lang['wrong_folder']          = '<strong>Zásuvný modul nesprávně nainstalován:</strong> Přejmenujte adresář modulu "%s" na "%s".';
$lang['url_change']            = '<strong>URL se změnila:</strong> URL pro stahování se změnila od poslední aktualizace. Před další aktualizací tohoto rozšíření ověřte správnost nové URL.<br />Nová: %s<br />Stará: %s';
$lang['error_badurl']          = 'Adresy URL by měly začínat s http nebo https';
$lang['error_dircreate']       = 'Nelze vytvořit dočasný adresář pro přijetí stahování';
$lang['error_download']        = 'Nelze stáhnout soubor: %s';
$lang['error_decompress']      = 'Selhalo rozbalení staženého souboru. Toto je nejspíš důsledek poškození souboru při přenosu, zkuste soubor stáhnout znovu; případně nemusel být rozpoznán formát sbaleného souboru a bude třeba přistoupit k ruční instalaci. ';
$lang['error_findfolder']      = 'Nelze rozpoznat adresář pro rozšíření, je třeba stáhnout a instalovat ručně';
$lang['error_copy']            = 'Došlo k chybě kopírování souborů při pokusu nainstalovat soubory do adresáře <em>%s</em>: může být plný disk nebo špatně nastavena přístupová práva. Tato chyba mohla zapříčinit pouze částečnou instalaci zásuvného modulu a uvést wiki do nestabilního stavu.';
$lang['noperms']               = 'Nelze zapisovat do adresáře pro rozšíření';
$lang['notplperms']            = 'Nelze zapisovat do odkládacího adresáře';
$lang['nopluginperms']         = 'Nelze zapisovat do adresáře se zásuvnými moduly';
$lang['git']                   = 'Toto rozšíření bylo nainstalováno přes git. Touto cestou ho nejspíš tady aktualizovat nechcete.';
$lang['auth']                  = 'Tento ověřovací zásuvný modul není povolen v nastavení, zvažte jeho deaktivaci.';
$lang['install_url']           = 'Nainstalovat z URL:';
$lang['install_upload']        = 'Nahrát rozšíření:';
$lang['repo_error']            = 'Nelze kontaktovat repozitář se zásuvnými moduly. Ujistěte se, že váš server může kontaktovat www.dokuwiki.org a zkontrolujte nastavení proxy.';
$lang['nossl']                 = 'Použité PHP pravděpodobně nepodporuje SSL. Stažení mnoha DokuWiki rozšíření nebude fungovat.';
